#include <libint2.h>

#ifdef __cplusplus
extern "C" {
#endif
void OSVRRP0InBra_aB_g__0__p__1___TwoPRep_s__0__s__1___Ab__up_0(const Libint_t* inteval, LIBINT2_REALTYPE* target, const LIBINT2_REALTYPE* src0, const LIBINT2_REALTYPE* src1, const LIBINT2_REALTYPE* src2, const LIBINT2_REALTYPE* src3, const LIBINT2_REALTYPE* src4) {

LIBINT2_REALTYPE*const  stack = target;
{
const int hsi = 0;
{
const int lsi = 0;
{
const int vi = 0;
LIBINT2_REALTYPE fp155;
fp155 = inteval->WP_z[vi] * src1[((hsi*30+10)*1+lsi)*1];
LIBINT2_REALTYPE fp156;
fp156 = inteval->PA_z[vi] * src0[((hsi*30+10)*1+lsi)*1];
LIBINT2_REALTYPE fp154;
fp154 = fp156 + fp155;
target[((hsi*45+22)*1+lsi)*1] = fp154;
LIBINT2_REALTYPE fp158;
fp158 = inteval->WP_z[vi] * src1[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp159;
fp159 = inteval->PA_z[vi] * src0[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp157;
fp157 = fp159 + fp158;
target[((hsi*45+21)*1+lsi)*1] = fp157;
LIBINT2_REALTYPE fp163;
fp163 = inteval->roz[vi] * src3[((hsi*18+5)*1+lsi)*1];
LIBINT2_REALTYPE fp162;
fp162 = src2[((hsi*18+5)*1+lsi)*1] - fp163;
LIBINT2_REALTYPE fp164;
fp164 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp161;
fp161 = fp164 * fp162;
LIBINT2_REALTYPE fp166;
fp166 = inteval->WP_y[vi] * src1[((hsi*30+11)*1+lsi)*1];
LIBINT2_REALTYPE fp167;
fp167 = inteval->PA_y[vi] * src0[((hsi*30+11)*1+lsi)*1];
LIBINT2_REALTYPE fp165;
fp165 = fp167 + fp166;
LIBINT2_REALTYPE fp160;
fp160 = fp165 + fp161;
target[((hsi*45+20)*1+lsi)*1] = fp160;
LIBINT2_REALTYPE fp169;
fp169 = inteval->oo2ze[vi] * src4[((hsi*10+3)*1+lsi)*1];
LIBINT2_REALTYPE fp173;
fp173 = inteval->roz[vi] * src3[((hsi*18+4)*1+lsi)*1];
LIBINT2_REALTYPE fp172;
fp172 = src2[((hsi*18+4)*1+lsi)*1] - fp173;
LIBINT2_REALTYPE fp174;
fp174 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp171;
fp171 = fp174 * fp172;
LIBINT2_REALTYPE fp176;
fp176 = inteval->WP_y[vi] * src1[((hsi*30+10)*1+lsi)*1];
LIBINT2_REALTYPE fp177;
fp177 = inteval->PA_y[vi] * src0[((hsi*30+10)*1+lsi)*1];
LIBINT2_REALTYPE fp175;
fp175 = fp177 + fp176;
LIBINT2_REALTYPE fp170;
fp170 = fp175 + fp171;
LIBINT2_REALTYPE fp168;
fp168 = fp170 + fp169;
target[((hsi*45+19)*1+lsi)*1] = fp168;
LIBINT2_REALTYPE fp181;
fp181 = inteval->roz[vi] * src3[((hsi*18+3)*1+lsi)*1];
LIBINT2_REALTYPE fp180;
fp180 = src2[((hsi*18+3)*1+lsi)*1] - fp181;
LIBINT2_REALTYPE fp182;
fp182 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp179;
fp179 = fp182 * fp180;
LIBINT2_REALTYPE fp184;
fp184 = inteval->WP_y[vi] * src1[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp185;
fp185 = inteval->PA_y[vi] * src0[((hsi*30+9)*1+lsi)*1];
LIBINT2_REALTYPE fp183;
fp183 = fp185 + fp184;
LIBINT2_REALTYPE fp178;
fp178 = fp183 + fp179;
target[((hsi*45+18)*1+lsi)*1] = fp178;
LIBINT2_REALTYPE fp187;
fp187 = inteval->oo2ze[vi] * src4[((hsi*10+2)*1+lsi)*1];
LIBINT2_REALTYPE fp256;
fp256 = inteval->roz[vi] * src3[((hsi*18+2)*1+lsi)*1];
LIBINT2_REALTYPE fp255;
fp255 = src2[((hsi*18+2)*1+lsi)*1] - fp256;
LIBINT2_REALTYPE fp189;
fp189 = inteval->oo2z[vi] * fp255;
LIBINT2_REALTYPE fp191;
fp191 = inteval->WP_z[vi] * src1[((hsi*30+8)*1+lsi)*1];
LIBINT2_REALTYPE fp192;
fp192 = inteval->PA_z[vi] * src0[((hsi*30+8)*1+lsi)*1];
LIBINT2_REALTYPE fp190;
fp190 = fp192 + fp191;
LIBINT2_REALTYPE fp188;
fp188 = fp190 + fp189;
LIBINT2_REALTYPE fp186;
fp186 = fp188 + fp187;
target[((hsi*45+17)*1+lsi)*1] = fp186;
LIBINT2_REALTYPE fp264;
fp264 = inteval->roz[vi] * src3[((hsi*18+1)*1+lsi)*1];
LIBINT2_REALTYPE fp263;
fp263 = src2[((hsi*18+1)*1+lsi)*1] - fp264;
LIBINT2_REALTYPE fp194;
fp194 = inteval->oo2z[vi] * fp263;
LIBINT2_REALTYPE fp196;
fp196 = inteval->WP_z[vi] * src1[((hsi*30+7)*1+lsi)*1];
LIBINT2_REALTYPE fp197;
fp197 = inteval->PA_z[vi] * src0[((hsi*30+7)*1+lsi)*1];
LIBINT2_REALTYPE fp195;
fp195 = fp197 + fp196;
LIBINT2_REALTYPE fp193;
fp193 = fp195 + fp194;
target[((hsi*45+16)*1+lsi)*1] = fp193;
LIBINT2_REALTYPE fp274;
fp274 = inteval->roz[vi] * src3[((hsi*18+0)*1+lsi)*1];
LIBINT2_REALTYPE fp273;
fp273 = src2[((hsi*18+0)*1+lsi)*1] - fp274;
LIBINT2_REALTYPE fp199;
fp199 = inteval->oo2z[vi] * fp273;
LIBINT2_REALTYPE fp201;
fp201 = inteval->WP_z[vi] * src1[((hsi*30+6)*1+lsi)*1];
LIBINT2_REALTYPE fp202;
fp202 = inteval->PA_z[vi] * src0[((hsi*30+6)*1+lsi)*1];
LIBINT2_REALTYPE fp200;
fp200 = fp202 + fp201;
LIBINT2_REALTYPE fp198;
fp198 = fp200 + fp199;
target[((hsi*45+15)*1+lsi)*1] = fp198;
LIBINT2_REALTYPE fp204;
fp204 = inteval->oo2ze[vi] * src4[((hsi*10+1)*1+lsi)*1];
LIBINT2_REALTYPE fp206;
fp206 = inteval->WP_z[vi] * src1[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp207;
fp207 = inteval->PA_z[vi] * src0[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp205;
fp205 = fp207 + fp206;
LIBINT2_REALTYPE fp203;
fp203 = fp205 + fp204;
target[((hsi*45+14)*1+lsi)*1] = fp203;
LIBINT2_REALTYPE fp209;
fp209 = inteval->WP_z[vi] * src1[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp210;
fp210 = inteval->PA_z[vi] * src0[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp208;
fp208 = fp210 + fp209;
target[((hsi*45+13)*1+lsi)*1] = fp208;
LIBINT2_REALTYPE fp212;
fp212 = inteval->WP_z[vi] * src1[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp213;
fp213 = inteval->PA_z[vi] * src0[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp211;
fp211 = fp213 + fp212;
target[((hsi*45+12)*1+lsi)*1] = fp211;
LIBINT2_REALTYPE fp215;
fp215 = inteval->oo2z[vi] * fp255;
LIBINT2_REALTYPE fp217;
fp217 = inteval->WP_y[vi] * src1[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp218;
fp218 = inteval->PA_y[vi] * src0[((hsi*30+5)*1+lsi)*1];
LIBINT2_REALTYPE fp216;
fp216 = fp218 + fp217;
LIBINT2_REALTYPE fp214;
fp214 = fp216 + fp215;
target[((hsi*45+11)*1+lsi)*1] = fp214;
LIBINT2_REALTYPE fp220;
fp220 = inteval->oo2ze[vi] * src4[((hsi*10+1)*1+lsi)*1];
LIBINT2_REALTYPE fp222;
fp222 = inteval->oo2z[vi] * fp263;
LIBINT2_REALTYPE fp224;
fp224 = inteval->WP_y[vi] * src1[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp225;
fp225 = inteval->PA_y[vi] * src0[((hsi*30+4)*1+lsi)*1];
LIBINT2_REALTYPE fp223;
fp223 = fp225 + fp224;
LIBINT2_REALTYPE fp221;
fp221 = fp223 + fp222;
LIBINT2_REALTYPE fp219;
fp219 = fp221 + fp220;
target[((hsi*45+10)*1+lsi)*1] = fp219;
LIBINT2_REALTYPE fp227;
fp227 = inteval->oo2z[vi] * fp273;
LIBINT2_REALTYPE fp229;
fp229 = inteval->WP_y[vi] * src1[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp230;
fp230 = inteval->PA_y[vi] * src0[((hsi*30+3)*1+lsi)*1];
LIBINT2_REALTYPE fp228;
fp228 = fp230 + fp229;
LIBINT2_REALTYPE fp226;
fp226 = fp228 + fp227;
target[((hsi*45+9)*1+lsi)*1] = fp226;
LIBINT2_REALTYPE fp232;
fp232 = inteval->oo2ze[vi] * src4[((hsi*10+0)*1+lsi)*1];
LIBINT2_REALTYPE fp234;
fp234 = inteval->WP_z[vi] * src1[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp235;
fp235 = inteval->PA_z[vi] * src0[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp233;
fp233 = fp235 + fp234;
LIBINT2_REALTYPE fp231;
fp231 = fp233 + fp232;
target[((hsi*45+8)*1+lsi)*1] = fp231;
LIBINT2_REALTYPE fp237;
fp237 = inteval->WP_z[vi] * src1[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp238;
fp238 = inteval->PA_z[vi] * src0[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp236;
fp236 = fp238 + fp237;
target[((hsi*45+7)*1+lsi)*1] = fp236;
LIBINT2_REALTYPE fp240;
fp240 = inteval->WP_z[vi] * src1[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp241;
fp241 = inteval->PA_z[vi] * src0[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp239;
fp239 = fp241 + fp240;
target[((hsi*45+6)*1+lsi)*1] = fp239;
LIBINT2_REALTYPE fp243;
fp243 = inteval->WP_y[vi] * src1[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp244;
fp244 = inteval->PA_y[vi] * src0[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp242;
fp242 = fp244 + fp243;
target[((hsi*45+5)*1+lsi)*1] = fp242;
LIBINT2_REALTYPE fp246;
fp246 = inteval->oo2ze[vi] * src4[((hsi*10+0)*1+lsi)*1];
LIBINT2_REALTYPE fp248;
fp248 = inteval->WP_y[vi] * src1[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp249;
fp249 = inteval->PA_y[vi] * src0[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp247;
fp247 = fp249 + fp248;
LIBINT2_REALTYPE fp245;
fp245 = fp247 + fp246;
target[((hsi*45+4)*1+lsi)*1] = fp245;
LIBINT2_REALTYPE fp251;
fp251 = inteval->WP_y[vi] * src1[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp252;
fp252 = inteval->PA_y[vi] * src0[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp250;
fp250 = fp252 + fp251;
target[((hsi*45+3)*1+lsi)*1] = fp250;
LIBINT2_REALTYPE fp257;
fp257 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp254;
fp254 = fp257 * fp255;
LIBINT2_REALTYPE fp259;
fp259 = inteval->WP_x[vi] * src1[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp260;
fp260 = inteval->PA_x[vi] * src0[((hsi*30+2)*1+lsi)*1];
LIBINT2_REALTYPE fp258;
fp258 = fp260 + fp259;
LIBINT2_REALTYPE fp253;
fp253 = fp258 + fp254;
target[((hsi*45+2)*1+lsi)*1] = fp253;
LIBINT2_REALTYPE fp265;
fp265 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp262;
fp262 = fp265 * fp263;
LIBINT2_REALTYPE fp267;
fp267 = inteval->WP_x[vi] * src1[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp268;
fp268 = inteval->PA_x[vi] * src0[((hsi*30+1)*1+lsi)*1];
LIBINT2_REALTYPE fp266;
fp266 = fp268 + fp267;
LIBINT2_REALTYPE fp261;
fp261 = fp266 + fp262;
target[((hsi*45+1)*1+lsi)*1] = fp261;
LIBINT2_REALTYPE fp270;
fp270 = inteval->oo2ze[vi] * src4[((hsi*10+0)*1+lsi)*1];
LIBINT2_REALTYPE fp275;
fp275 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp272;
fp272 = fp275 * fp273;
LIBINT2_REALTYPE fp277;
fp277 = inteval->WP_x[vi] * src1[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp278;
fp278 = inteval->PA_x[vi] * src0[((hsi*30+0)*1+lsi)*1];
LIBINT2_REALTYPE fp276;
fp276 = fp278 + fp277;
LIBINT2_REALTYPE fp271;
fp271 = fp276 + fp272;
LIBINT2_REALTYPE fp269;
fp269 = fp271 + fp270;
target[((hsi*45+0)*1+lsi)*1] = fp269;
LIBINT2_REALTYPE fp1;
fp1 = inteval->oo2ze[vi] * src4[((hsi*10+9)*1+lsi)*1];
LIBINT2_REALTYPE fp5;
fp5 = inteval->roz[vi] * src3[((hsi*18+17)*1+lsi)*1];
LIBINT2_REALTYPE fp4;
fp4 = src2[((hsi*18+17)*1+lsi)*1] - fp5;
LIBINT2_REALTYPE fp6;
fp6 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp3;
fp3 = fp6 * fp4;
LIBINT2_REALTYPE fp8;
fp8 = inteval->WP_z[vi] * src1[((hsi*30+29)*1+lsi)*1];
LIBINT2_REALTYPE fp9;
fp9 = inteval->PA_z[vi] * src0[((hsi*30+29)*1+lsi)*1];
LIBINT2_REALTYPE fp7;
fp7 = fp9 + fp8;
LIBINT2_REALTYPE fp2;
fp2 = fp7 + fp3;
LIBINT2_REALTYPE fp0;
fp0 = fp2 + fp1;
target[((hsi*45+44)*1+lsi)*1] = fp0;
LIBINT2_REALTYPE fp13;
fp13 = inteval->roz[vi] * src3[((hsi*18+16)*1+lsi)*1];
LIBINT2_REALTYPE fp12;
fp12 = src2[((hsi*18+16)*1+lsi)*1] - fp13;
LIBINT2_REALTYPE fp14;
fp14 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp11;
fp11 = fp14 * fp12;
LIBINT2_REALTYPE fp16;
fp16 = inteval->WP_z[vi] * src1[((hsi*30+28)*1+lsi)*1];
LIBINT2_REALTYPE fp17;
fp17 = inteval->PA_z[vi] * src0[((hsi*30+28)*1+lsi)*1];
LIBINT2_REALTYPE fp15;
fp15 = fp17 + fp16;
LIBINT2_REALTYPE fp10;
fp10 = fp15 + fp11;
target[((hsi*45+43)*1+lsi)*1] = fp10;
LIBINT2_REALTYPE fp21;
fp21 = inteval->roz[vi] * src3[((hsi*18+15)*1+lsi)*1];
LIBINT2_REALTYPE fp20;
fp20 = src2[((hsi*18+15)*1+lsi)*1] - fp21;
LIBINT2_REALTYPE fp22;
fp22 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp19;
fp19 = fp22 * fp20;
LIBINT2_REALTYPE fp24;
fp24 = inteval->WP_z[vi] * src1[((hsi*30+27)*1+lsi)*1];
LIBINT2_REALTYPE fp25;
fp25 = inteval->PA_z[vi] * src0[((hsi*30+27)*1+lsi)*1];
LIBINT2_REALTYPE fp23;
fp23 = fp25 + fp24;
LIBINT2_REALTYPE fp18;
fp18 = fp23 + fp19;
target[((hsi*45+42)*1+lsi)*1] = fp18;
LIBINT2_REALTYPE fp27;
fp27 = inteval->oo2ze[vi] * src4[((hsi*10+8)*1+lsi)*1];
LIBINT2_REALTYPE fp31;
fp31 = inteval->roz[vi] * src3[((hsi*18+14)*1+lsi)*1];
LIBINT2_REALTYPE fp30;
fp30 = src2[((hsi*18+14)*1+lsi)*1] - fp31;
LIBINT2_REALTYPE fp32;
fp32 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp29;
fp29 = fp32 * fp30;
LIBINT2_REALTYPE fp34;
fp34 = inteval->WP_z[vi] * src1[((hsi*30+26)*1+lsi)*1];
LIBINT2_REALTYPE fp35;
fp35 = inteval->PA_z[vi] * src0[((hsi*30+26)*1+lsi)*1];
LIBINT2_REALTYPE fp33;
fp33 = fp35 + fp34;
LIBINT2_REALTYPE fp28;
fp28 = fp33 + fp29;
LIBINT2_REALTYPE fp26;
fp26 = fp28 + fp27;
target[((hsi*45+41)*1+lsi)*1] = fp26;
LIBINT2_REALTYPE fp39;
fp39 = inteval->roz[vi] * src3[((hsi*18+13)*1+lsi)*1];
LIBINT2_REALTYPE fp38;
fp38 = src2[((hsi*18+13)*1+lsi)*1] - fp39;
LIBINT2_REALTYPE fp40;
fp40 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp37;
fp37 = fp40 * fp38;
LIBINT2_REALTYPE fp42;
fp42 = inteval->WP_z[vi] * src1[((hsi*30+25)*1+lsi)*1];
LIBINT2_REALTYPE fp43;
fp43 = inteval->PA_z[vi] * src0[((hsi*30+25)*1+lsi)*1];
LIBINT2_REALTYPE fp41;
fp41 = fp43 + fp42;
LIBINT2_REALTYPE fp36;
fp36 = fp41 + fp37;
target[((hsi*45+40)*1+lsi)*1] = fp36;
LIBINT2_REALTYPE fp47;
fp47 = inteval->roz[vi] * src3[((hsi*18+12)*1+lsi)*1];
LIBINT2_REALTYPE fp46;
fp46 = src2[((hsi*18+12)*1+lsi)*1] - fp47;
LIBINT2_REALTYPE fp48;
fp48 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp45;
fp45 = fp48 * fp46;
LIBINT2_REALTYPE fp50;
fp50 = inteval->WP_z[vi] * src1[((hsi*30+24)*1+lsi)*1];
LIBINT2_REALTYPE fp51;
fp51 = inteval->PA_z[vi] * src0[((hsi*30+24)*1+lsi)*1];
LIBINT2_REALTYPE fp49;
fp49 = fp51 + fp50;
LIBINT2_REALTYPE fp44;
fp44 = fp49 + fp45;
target[((hsi*45+39)*1+lsi)*1] = fp44;
LIBINT2_REALTYPE fp53;
fp53 = inteval->oo2ze[vi] * src4[((hsi*10+7)*1+lsi)*1];
LIBINT2_REALTYPE fp83;
fp83 = inteval->roz[vi] * src3[((hsi*18+11)*1+lsi)*1];
LIBINT2_REALTYPE fp82;
fp82 = src2[((hsi*18+11)*1+lsi)*1] - fp83;
LIBINT2_REALTYPE fp55;
fp55 = inteval->oo2z[vi] * fp82;
LIBINT2_REALTYPE fp57;
fp57 = inteval->WP_z[vi] * src1[((hsi*30+23)*1+lsi)*1];
LIBINT2_REALTYPE fp58;
fp58 = inteval->PA_z[vi] * src0[((hsi*30+23)*1+lsi)*1];
LIBINT2_REALTYPE fp56;
fp56 = fp58 + fp57;
LIBINT2_REALTYPE fp54;
fp54 = fp56 + fp55;
LIBINT2_REALTYPE fp52;
fp52 = fp54 + fp53;
target[((hsi*45+38)*1+lsi)*1] = fp52;
LIBINT2_REALTYPE fp93;
fp93 = inteval->roz[vi] * src3[((hsi*18+10)*1+lsi)*1];
LIBINT2_REALTYPE fp92;
fp92 = src2[((hsi*18+10)*1+lsi)*1] - fp93;
LIBINT2_REALTYPE fp60;
fp60 = inteval->oo2z[vi] * fp92;
LIBINT2_REALTYPE fp62;
fp62 = inteval->WP_z[vi] * src1[((hsi*30+22)*1+lsi)*1];
LIBINT2_REALTYPE fp63;
fp63 = inteval->PA_z[vi] * src0[((hsi*30+22)*1+lsi)*1];
LIBINT2_REALTYPE fp61;
fp61 = fp63 + fp62;
LIBINT2_REALTYPE fp59;
fp59 = fp61 + fp60;
target[((hsi*45+37)*1+lsi)*1] = fp59;
LIBINT2_REALTYPE fp101;
fp101 = inteval->roz[vi] * src3[((hsi*18+9)*1+lsi)*1];
LIBINT2_REALTYPE fp100;
fp100 = src2[((hsi*18+9)*1+lsi)*1] - fp101;
LIBINT2_REALTYPE fp65;
fp65 = inteval->oo2z[vi] * fp100;
LIBINT2_REALTYPE fp67;
fp67 = inteval->WP_z[vi] * src1[((hsi*30+21)*1+lsi)*1];
LIBINT2_REALTYPE fp68;
fp68 = inteval->PA_z[vi] * src0[((hsi*30+21)*1+lsi)*1];
LIBINT2_REALTYPE fp66;
fp66 = fp68 + fp67;
LIBINT2_REALTYPE fp64;
fp64 = fp66 + fp65;
target[((hsi*45+36)*1+lsi)*1] = fp64;
LIBINT2_REALTYPE fp70;
fp70 = inteval->oo2ze[vi] * src4[((hsi*10+6)*1+lsi)*1];
LIBINT2_REALTYPE fp72;
fp72 = inteval->WP_z[vi] * src1[((hsi*30+20)*1+lsi)*1];
LIBINT2_REALTYPE fp73;
fp73 = inteval->PA_z[vi] * src0[((hsi*30+20)*1+lsi)*1];
LIBINT2_REALTYPE fp71;
fp71 = fp73 + fp72;
LIBINT2_REALTYPE fp69;
fp69 = fp71 + fp70;
target[((hsi*45+35)*1+lsi)*1] = fp69;
LIBINT2_REALTYPE fp75;
fp75 = inteval->WP_z[vi] * src1[((hsi*30+19)*1+lsi)*1];
LIBINT2_REALTYPE fp76;
fp76 = inteval->PA_z[vi] * src0[((hsi*30+19)*1+lsi)*1];
LIBINT2_REALTYPE fp74;
fp74 = fp76 + fp75;
target[((hsi*45+34)*1+lsi)*1] = fp74;
LIBINT2_REALTYPE fp78;
fp78 = inteval->WP_z[vi] * src1[((hsi*30+18)*1+lsi)*1];
LIBINT2_REALTYPE fp79;
fp79 = inteval->PA_z[vi] * src0[((hsi*30+18)*1+lsi)*1];
LIBINT2_REALTYPE fp77;
fp77 = fp79 + fp78;
target[((hsi*45+33)*1+lsi)*1] = fp77;
LIBINT2_REALTYPE fp84;
fp84 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp81;
fp81 = fp84 * fp82;
LIBINT2_REALTYPE fp86;
fp86 = inteval->WP_y[vi] * src1[((hsi*30+20)*1+lsi)*1];
LIBINT2_REALTYPE fp87;
fp87 = inteval->PA_y[vi] * src0[((hsi*30+20)*1+lsi)*1];
LIBINT2_REALTYPE fp85;
fp85 = fp87 + fp86;
LIBINT2_REALTYPE fp80;
fp80 = fp85 + fp81;
target[((hsi*45+32)*1+lsi)*1] = fp80;
LIBINT2_REALTYPE fp89;
fp89 = inteval->oo2ze[vi] * src4[((hsi*10+6)*1+lsi)*1];
LIBINT2_REALTYPE fp94;
fp94 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp91;
fp91 = fp94 * fp92;
LIBINT2_REALTYPE fp96;
fp96 = inteval->WP_y[vi] * src1[((hsi*30+19)*1+lsi)*1];
LIBINT2_REALTYPE fp97;
fp97 = inteval->PA_y[vi] * src0[((hsi*30+19)*1+lsi)*1];
LIBINT2_REALTYPE fp95;
fp95 = fp97 + fp96;
LIBINT2_REALTYPE fp90;
fp90 = fp95 + fp91;
LIBINT2_REALTYPE fp88;
fp88 = fp90 + fp89;
target[((hsi*45+31)*1+lsi)*1] = fp88;
LIBINT2_REALTYPE fp102;
fp102 = 3 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp99;
fp99 = fp102 * fp100;
LIBINT2_REALTYPE fp104;
fp104 = inteval->WP_y[vi] * src1[((hsi*30+18)*1+lsi)*1];
LIBINT2_REALTYPE fp105;
fp105 = inteval->PA_y[vi] * src0[((hsi*30+18)*1+lsi)*1];
LIBINT2_REALTYPE fp103;
fp103 = fp105 + fp104;
LIBINT2_REALTYPE fp98;
fp98 = fp103 + fp99;
target[((hsi*45+30)*1+lsi)*1] = fp98;
LIBINT2_REALTYPE fp107;
fp107 = inteval->oo2ze[vi] * src4[((hsi*10+5)*1+lsi)*1];
LIBINT2_REALTYPE fp111;
fp111 = inteval->roz[vi] * src3[((hsi*18+8)*1+lsi)*1];
LIBINT2_REALTYPE fp110;
fp110 = src2[((hsi*18+8)*1+lsi)*1] - fp111;
LIBINT2_REALTYPE fp112;
fp112 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp109;
fp109 = fp112 * fp110;
LIBINT2_REALTYPE fp114;
fp114 = inteval->WP_z[vi] * src1[((hsi*30+17)*1+lsi)*1];
LIBINT2_REALTYPE fp115;
fp115 = inteval->PA_z[vi] * src0[((hsi*30+17)*1+lsi)*1];
LIBINT2_REALTYPE fp113;
fp113 = fp115 + fp114;
LIBINT2_REALTYPE fp108;
fp108 = fp113 + fp109;
LIBINT2_REALTYPE fp106;
fp106 = fp108 + fp107;
target[((hsi*45+29)*1+lsi)*1] = fp106;
LIBINT2_REALTYPE fp119;
fp119 = inteval->roz[vi] * src3[((hsi*18+7)*1+lsi)*1];
LIBINT2_REALTYPE fp118;
fp118 = src2[((hsi*18+7)*1+lsi)*1] - fp119;
LIBINT2_REALTYPE fp120;
fp120 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp117;
fp117 = fp120 * fp118;
LIBINT2_REALTYPE fp122;
fp122 = inteval->WP_z[vi] * src1[((hsi*30+16)*1+lsi)*1];
LIBINT2_REALTYPE fp123;
fp123 = inteval->PA_z[vi] * src0[((hsi*30+16)*1+lsi)*1];
LIBINT2_REALTYPE fp121;
fp121 = fp123 + fp122;
LIBINT2_REALTYPE fp116;
fp116 = fp121 + fp117;
target[((hsi*45+28)*1+lsi)*1] = fp116;
LIBINT2_REALTYPE fp127;
fp127 = inteval->roz[vi] * src3[((hsi*18+6)*1+lsi)*1];
LIBINT2_REALTYPE fp126;
fp126 = src2[((hsi*18+6)*1+lsi)*1] - fp127;
LIBINT2_REALTYPE fp128;
fp128 = 2 * inteval->oo2z[vi];
LIBINT2_REALTYPE fp125;
fp125 = fp128 * fp126;
LIBINT2_REALTYPE fp130;
fp130 = inteval->WP_z[vi] * src1[((hsi*30+15)*1+lsi)*1];
LIBINT2_REALTYPE fp131;
fp131 = inteval->PA_z[vi] * src0[((hsi*30+15)*1+lsi)*1];
LIBINT2_REALTYPE fp129;
fp129 = fp131 + fp130;
LIBINT2_REALTYPE fp124;
fp124 = fp129 + fp125;
target[((hsi*45+27)*1+lsi)*1] = fp124;
LIBINT2_REALTYPE fp133;
fp133 = inteval->oo2ze[vi] * src4[((hsi*10+4)*1+lsi)*1];
LIBINT2_REALTYPE fp135;
fp135 = inteval->oo2z[vi] * fp162;
LIBINT2_REALTYPE fp137;
fp137 = inteval->WP_z[vi] * src1[((hsi*30+14)*1+lsi)*1];
LIBINT2_REALTYPE fp138;
fp138 = inteval->PA_z[vi] * src0[((hsi*30+14)*1+lsi)*1];
LIBINT2_REALTYPE fp136;
fp136 = fp138 + fp137;
LIBINT2_REALTYPE fp134;
fp134 = fp136 + fp135;
LIBINT2_REALTYPE fp132;
fp132 = fp134 + fp133;
target[((hsi*45+26)*1+lsi)*1] = fp132;
LIBINT2_REALTYPE fp140;
fp140 = inteval->oo2z[vi] * fp172;
LIBINT2_REALTYPE fp142;
fp142 = inteval->WP_z[vi] * src1[((hsi*30+13)*1+lsi)*1];
LIBINT2_REALTYPE fp143;
fp143 = inteval->PA_z[vi] * src0[((hsi*30+13)*1+lsi)*1];
LIBINT2_REALTYPE fp141;
fp141 = fp143 + fp142;
LIBINT2_REALTYPE fp139;
fp139 = fp141 + fp140;
target[((hsi*45+25)*1+lsi)*1] = fp139;
LIBINT2_REALTYPE fp145;
fp145 = inteval->oo2z[vi] * fp180;
LIBINT2_REALTYPE fp147;
fp147 = inteval->WP_z[vi] * src1[((hsi*30+12)*1+lsi)*1];
LIBINT2_REALTYPE fp148;
fp148 = inteval->PA_z[vi] * src0[((hsi*30+12)*1+lsi)*1];
LIBINT2_REALTYPE fp146;
fp146 = fp148 + fp147;
LIBINT2_REALTYPE fp144;
fp144 = fp146 + fp145;
target[((hsi*45+24)*1+lsi)*1] = fp144;
LIBINT2_REALTYPE fp150;
fp150 = inteval->oo2ze[vi] * src4[((hsi*10+3)*1+lsi)*1];
LIBINT2_REALTYPE fp152;
fp152 = inteval->WP_z[vi] * src1[((hsi*30+11)*1+lsi)*1];
LIBINT2_REALTYPE fp153;
fp153 = inteval->PA_z[vi] * src0[((hsi*30+11)*1+lsi)*1];
LIBINT2_REALTYPE fp151;
fp151 = fp153 + fp152;
LIBINT2_REALTYPE fp149;
fp149 = fp151 + fp150;
target[((hsi*45+23)*1+lsi)*1] = fp149;
}
}
}
const int hsi = 0;
const int lsi = 0;
const int vi = 0;
/** Number of flops = 279 */
}

#ifdef __cplusplus
};
#endif
